@@ -16,9 +16,9 @@ from cubicweb.utils import transitive_closure_of
 from cubicweb.schema import META_RTYPES
 from cubicweb.selectors import is_instance
 from cubicweb.server import hook
-from cubicweb.server.hook import (Hook, PropagateSubjectRelationHook,
-                                  PropagateSubjectRelationAddHook,
-                                  PropagateSubjectRelationDelHook,
+from cubicweb.server.hook import (Hook, PropagateRelationHook,
+                                  PropagateRelationAddHook,
+                                  PropagateRelationDelHook,
                                   match_rtype, match_rtype_sets)
 from cubicweb.hooks import notification
 
@@ -97,8 +97,7 @@ class TicketStatusChangeHook(Hook):
                     idiwf.fire_transition(tr.name, trinfo.comment,
                                           trinfo.comment_format)
                 except:
-                    self.exception("can't synchronize identical ticket's state",
-                                   exc_info=True)
+                    self.exception("can't synchronize identical ticket's state")
 
 # verification hooks ###########################################################
 
@@ -183,28 +182,39 @@ O_RELS = set(('concerns', 'version_of', 'subproject_of'))
 #
 # XXX: see_also
 
+# relations where the "main" entity is the subject/object that should be skipped
+# when propagating to entities linked through some particular relation
+SKIP_S_RELS = set()
+SKIP_O_RELS = set()
 
-class AddEntitySecurityPropagationHook(PropagateSubjectRelationHook):
+
+class AddEntitySecurityPropagationHook(PropagateRelationHook):
     """propagate permissions when new entity are added"""
     __regid__ = 'add_entity_security_propagation'
-    __select__ = PropagateSubjectRelationHook.__select__ & match_rtype_sets(S_RELS, O_RELS)
+    __select__ = (PropagateRelationHook.__select__
+                  & match_rtype_sets(S_RELS, O_RELS))
     main_rtype = 'require_permission'
     subject_relations = S_RELS
     object_relations = O_RELS
 
 
-class AddPermissionSecurityPropagationHook(PropagateSubjectRelationAddHook):
-    """propagate permissions when new entity are added"""
+class AddPermissionSecurityPropagationHook(PropagateRelationAddHook):
     __regid__ = 'add_permission_security_propagation'
-    __select__ = PropagateSubjectRelationAddHook.__select__ & hook.match_rtype('require_permission',)
+    __select__ = (PropagateRelationAddHook.__select__
+                  & hook.match_rtype('require_permission'))
     subject_relations = S_RELS
     object_relations = O_RELS
+    skip_subject_relations = SKIP_S_RELS
+    skip_object_relations = SKIP_O_RELS
 
-class DelPermissionSecurityPropagationHook(PropagateSubjectRelationDelHook):
+class DelPermissionSecurityPropagationHook(PropagateRelationDelHook):
     __regid__ = 'del_permission_security_propagation'
-    __select__ = PropagateSubjectRelationDelHook.__select__ & hook.match_rtype('require_permission',)
+    __select__ = (PropagateRelationDelHook.__select__
+                  & hook.match_rtype('require_permission'))
     subject_relations = S_RELS
     object_relations = O_RELS
+    skip_subject_relations = SKIP_S_RELS
+    skip_object_relations = SKIP_O_RELS
 
 
 # has_group_permission propagation hooks #######################################
