@@ -35,10 +35,10 @@ class TrackerTests(TrackerBaseTC):
         t1.cw_adapt_to('IWorkflowable').fire_transition('close')
         self.commit()
         t2.clear_all_caches()
-        self.assertEquals(t2.cw_adapt_to('IWorkflowable').state, 'closed')
+        self.assertEqual(t2.cw_adapt_to('IWorkflowable').state, 'closed')
         self.execute('SET X done_in V WHERE X eid %(x)s, V is Version',
                      {'x':t1.eid})
-        self.assertEquals(t2.done_in[0].eid, veid)
+        self.assertEqual(t2.done_in[0].eid, veid)
         self.commit()
 
 
@@ -55,18 +55,18 @@ class ProjectTC(TrackerBaseTC):
         self.commit()
         v1.cw_adapt_to('IWorkflowable').fire_transition('start development')
         vrset = self.cubicweb.versions_in_state(('planned', 'dev'))
-        self.assertEquals(len(vrset), 2)
-        self.assertEquals(vrset[0][0], v1.eid)
-        self.assertEquals(vrset[1][0], v2.eid)
+        self.assertEqual(len(vrset), 2)
+        self.assertEqual(vrset[0][0], v1.eid)
+        self.assertEqual(vrset[1][0], v2.eid)
         vrset = self.cubicweb.versions_in_state(('planned',))
-        self.assertEquals(len(vrset), 1)
-        self.assertEquals(vrset[0][0], v2.eid)
+        self.assertEqual(len(vrset), 1)
+        self.assertEqual(vrset[0][0], v2.eid)
 
     def test_possible_actions(self):
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
         self.commit()
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('edit', actions.ModifyAction),
                                ('managepermission', actions.ManagePermissionsAction),
                                ('addrelated', actions.AddRelatedActions),
@@ -74,7 +74,7 @@ class ProjectTC(TrackerBaseTC):
                                ('copy', actions.CopyAction),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [(u'add Project subproject_of Project object',
                                 u'http://testing.fr/cubicweb/add/Project?__linkto=subproject_of%%3A%s%%3Asubject&__redirectpath=project%%2Fcubicweb&__redirectvid=' % self.cubicweb.eid),
                                (u'add Ticket concerns Project object',
@@ -84,18 +84,18 @@ class ProjectTC(TrackerBaseTC):
         self.login('anon')
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('addrelated', actions.AddRelatedActions),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
 
     def test_versions_order(self):
         veid1, = self.create_version(u'0.0.0')[0]
         veid2, = self.create_version(u'0.1.0')[0]
         veid3, = self.create_version(u'0.0.1')[0]
-        self.assertEquals([v.eid for v in self.cubicweb.reverse_version_of],
+        self.assertEqual([v.eid for v in self.cubicweb.reverse_version_of],
                           [veid2, veid3, veid1])
 
 
@@ -114,18 +114,18 @@ class VersionTC(TrackerBaseTC):
         self.login('anon')
         req = self.request()
         rset = req.execute('Any X WHERE X is Version, X num "0.0.0"')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('addrelated', actions.AddRelatedActions),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
         if with_hist:
-            self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+            self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                                   [(u'view history', u'http://testing.fr/cubicweb/project/cubicweb/0.0.0?vid=wfhistory')])
         else:
-            self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+            self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                                   [])
 
     def test_possible_actions_and_transitions(self):
@@ -137,7 +137,7 @@ class VersionTC(TrackerBaseTC):
         # one planned version
         rset = req.execute('Any X WHERE X is Version, X num "0.0.0"')
         wf = self.v.cw_adapt_to('IWorkflowable').current_workflow
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('edit', actions.ModifyAction),
                                ('managepermission', actions.ManagePermissionsAction),
@@ -147,16 +147,16 @@ class VersionTC(TrackerBaseTC):
                                ('addticket', version.VersionAddTicketAction),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'start development', u'http://testing.fr/cubicweb/project/cubicweb/0.0.0?treid=%s&vid=statuschange' %
                                 wf.transition_by_name('start development').eid),
                                (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid)])
         self.login('toto') #####################################################
         req = self.request()
         rset = req.execute('Any X WHERE X is Version, X num "0.0.0"')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('edit', actions.ModifyAction),
                                ('addrelated', actions.AddRelatedActions),
@@ -164,9 +164,9 @@ class VersionTC(TrackerBaseTC):
                                ('addticket', version.VersionAddTicketAction),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [])
         self._test_anon_actions(False) #########################################
         self.restore_connection() ##############################################
@@ -175,7 +175,7 @@ class VersionTC(TrackerBaseTC):
         self.commit()
         req = self.request()
         rset = req.execute('Any X WHERE X is Version, X num "0.0.0"')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                              [('workflow', workflow.WorkflowActions),
                               ('edit', actions.ModifyAction),
                               ('managepermission', actions.ManagePermissionsAction),
@@ -185,9 +185,9 @@ class VersionTC(TrackerBaseTC):
                               ('addticket', version.VersionAddTicketAction),
                               ('pvrestexport', document.ProjectVersionExportAction),
                               ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'ready', u'http://testing.fr/cubicweb/project/cubicweb/0.0.0?treid=%s&vid=statuschange' %
                                 wf.transition_by_name('ready').eid),
                                (u'publish', u'http://testing.fr/cubicweb/project/cubicweb/0.0.0?treid=%s&vid=statuschange' %
@@ -199,16 +199,16 @@ class VersionTC(TrackerBaseTC):
         self.login('toto') #####################################################
         req = self.request()
         rset = req.execute('Any X WHERE X is Version, X num "0.0.0"')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('edit', actions.ModifyAction),
                                ('addrelated', actions.AddRelatedActions),
                                ('copy', actions.CopyAction),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'view history', u'http://testing.fr/cubicweb/project/cubicweb/0.0.0?vid=wfhistory')])
         self._test_anon_actions() ##############################################
         self.restore_connection() ##############################################
@@ -217,7 +217,7 @@ class VersionTC(TrackerBaseTC):
         self.commit()
         req = self.request()
         rset = req.execute('Any X WHERE X is Version, X num "0.0.0"')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                              [('workflow', workflow.WorkflowActions),
                               ('edit', actions.ModifyAction),
                               ('managepermission', actions.ManagePermissionsAction),
@@ -226,9 +226,9 @@ class VersionTC(TrackerBaseTC):
                               ('copy', actions.CopyAction),
                               ('pvrestexport', document.ProjectVersionExportAction),
                               ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'publish', u'http://testing.fr/cubicweb/project/cubicweb/0.0.0?treid=%s&vid=statuschange' %
                                 wf.transition_by_name('publish').eid),
                                (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s' % wf.eid),
@@ -236,16 +236,16 @@ class VersionTC(TrackerBaseTC):
         self.login('toto') #####################################################
         req = self.request()
         rset = req.execute('Any X WHERE X is Version, X num "0.0.0"')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('edit', actions.ModifyAction),
                                ('addrelated', actions.AddRelatedActions),
                                ('copy', actions.CopyAction),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'view history', u'http://testing.fr/cubicweb/project/cubicweb/0.0.0?vid=wfhistory')])
         self._test_anon_actions() ##############################################
         self.restore_connection() ##############################################
@@ -254,7 +254,7 @@ class VersionTC(TrackerBaseTC):
         self.commit()
         req = self.request()
         rset = req.execute('Any X WHERE X is Version, X num "0.0.0"')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('edit', actions.ModifyAction),
                                ('managepermission', actions.ManagePermissionsAction),
@@ -264,14 +264,14 @@ class VersionTC(TrackerBaseTC):
                                ('submitbug', version.VersionSubmitBugAction),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'view history', u'http://testing.fr/cubicweb/project/cubicweb/0.0.0?vid=wfhistory')])
         self.login('toto') #####################################################
         req = self.request()
         rset = req.execute('Any X WHERE X is Version, X num "0.0.0"')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('edit', actions.ModifyAction),
                                ('addrelated', actions.AddRelatedActions),
@@ -279,9 +279,9 @@ class VersionTC(TrackerBaseTC):
                                ('submitbug', version.VersionSubmitBugAction),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'view history', u'http://testing.fr/cubicweb/project/cubicweb/0.0.0?vid=wfhistory')])
         self._test_anon_actions() ##############################################
 
@@ -289,18 +289,18 @@ class VersionTC(TrackerBaseTC):
         self.t1.cw_adapt_to('IWorkflowable').fire_transition('start')
         self.commit()
         self.v.clear_all_caches()
-        self.assertEquals(self.v.cw_adapt_to('IWorkflowable').state, 'dev')
+        self.assertEqual(self.v.cw_adapt_to('IWorkflowable').state, 'dev')
 
     def test_next_version(self):
         v2 = self.create_version("0.0.1").get_entity(0, 0)
         self.commit()
-        self.assertEquals(self.v.next_version().num, v2.num)
-        self.assertEquals(self.v.next_version(('dev',)), None)
-        self.assertEquals(v2.next_version(), None)
+        self.assertEqual(self.v.next_version().num, v2.num)
+        self.assertEqual(self.v.next_version(('dev',)), None)
+        self.assertEqual(v2.next_version(), None)
 
     def test_duplicated_version(self):
         ex = self.assertRaises(ValidationError, self.create_version, u'0.0.0')
-        self.assertEquals(ex.errors,
+        self.assertEqual(ex.errors,
                           {'num': u'0.0.0 release number already exists for the project cubicweb'})
 
     def test_status_change_form(self):
@@ -309,11 +309,11 @@ class VersionTC(TrackerBaseTC):
         tr = req.execute('Transition X WHERE X name "start development"').get_entity(0, 0)
         form = self.vreg['forms'].select('changestate', req, transition=tr,
                                          rset=rset, row=0, col=0)
-        self.assertEquals(form.__class__, workflow.ChangeStateForm)
+        self.assertEqual(form.__class__, workflow.ChangeStateForm)
         tr = req.execute('Transition X WHERE X name "publish"').get_entity(0, 0)
         form = self.vreg['forms'].select('changestate', req, transition=tr,
                                          rset=rset, row=0, col=0)
-        self.assertEquals(form.__class__, forms.VersionChangeStateForm)
+        self.assertEqual(form.__class__, forms.VersionChangeStateForm)
 
 
 class TicketTC(TrackerBaseTC):
@@ -335,7 +335,7 @@ class TicketTC(TrackerBaseTC):
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
         wf = self.t1.cw_adapt_to('IWorkflowable').current_workflow
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                              [('workflow', workflow.WorkflowActions),
                               ('edit', actions.ModifyAction),
                               ('managepermission', actions.ManagePermissionsAction),
@@ -343,9 +343,9 @@ class TicketTC(TrackerBaseTC):
                               ('delete', actions.DeleteAction),
                               ('copy', actions.CopyAction),
                               ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'start',
                                 u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
                                 (self.t1.eid, wf.transition_by_name('start').eid)),
@@ -357,20 +357,20 @@ class TicketTC(TrackerBaseTC):
         self.login('anon') #####################################################
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('addrelated', actions.AddRelatedActions),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [])
         self.restore_connection() ##############################################
         self.t1.cw_adapt_to('IWorkflowable').fire_transition('start')
         self.commit()
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                              [('workflow', workflow.WorkflowActions),
                               ('edit', actions.ModifyAction),
                               ('managepermission', actions.ManagePermissionsAction),
@@ -379,9 +379,9 @@ class TicketTC(TrackerBaseTC):
                               ('copy', actions.CopyAction),
                               ('movetonext', ticket.TicketMoveToNextVersionActions),
                               ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'close',
                                 u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
                                 (self.t1.eid, wf.transition_by_name('close').eid)),
@@ -392,20 +392,20 @@ class TicketTC(TrackerBaseTC):
         self.login('anon') #####################################################
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('addrelated', actions.AddRelatedActions),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
         self.restore_connection() ##############################################
         self.t1.cw_adapt_to('IWorkflowable').fire_transition('close')
         self.commit()
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                              [('workflow', workflow.WorkflowActions),
                               ('edit', actions.ModifyAction),
                               ('managepermission', actions.ManagePermissionsAction),
@@ -413,20 +413,20 @@ class TicketTC(TrackerBaseTC):
                               ('delete', actions.DeleteAction),
                               ('copy', actions.CopyAction),
                               ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
         self.login('anon') #####################################################
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
-        self.assertListEquals(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                               [('workflow', workflow.WorkflowActions),
                                ('addrelated', actions.AddRelatedActions),
                                ])
-        self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
+        self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
-        self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
+        self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
 
     def test_nonregr_anon_move_ticket(self):
@@ -436,10 +436,10 @@ class TicketTC(TrackerBaseTC):
 
     def test_nonregr_ticket_breadcrumbs(self):
         bcrumbs = [x.eid for x in self.t1.cw_adapt_to('IBreadCrumbs').breadcrumbs()]
-        self.assertEquals(bcrumbs, [self.t1.project.eid, self.t1.eid])
+        self.assertEqual(bcrumbs, [self.t1.project.eid, self.t1.eid])
         view = mock_object(__regid__='primary')
         bcrumbs = [x.eid for x in self.t1.cw_adapt_to('IBreadCrumbs').breadcrumbs(view)]
-        self.assertEquals(bcrumbs, [self.t1.project.eid, self.t1.eid])
+        self.assertEqual(bcrumbs, [self.t1.project.eid, self.t1.eid])
 
 
 class CreationTC(TrackerBaseTC):
@@ -458,10 +458,10 @@ class CreationTC(TrackerBaseTC):
             '__redirectpath' : '/project/cubicweb',
             })
         path, _params = self.expect_redirect_publish(req)
-        self.assertEquals(path, '/project/cubicweb')
+        self.assertEqual(path, '/project/cubicweb')
         rset = self.execute('Any N WHERE V num N, V version_of P, P eid %s' % self.cubicweb.eid)
         self.failUnless(len(rset) == 1)
-        self.assertEquals(rset[0][0], u"3.0")
+        self.assertEqual(rset[0][0], u"3.0")
 
 
 class SubProjectTC(CubicWebTC):
@@ -563,10 +563,10 @@ class SubProjectTC(CubicWebTC):
     def test_deps_order(self):
         comet_children_eids = set(p.eid for p in transitive_closure_of(
             self.comet, 'reverse_subproject_of'))
-        self.assertEquals(len(comet_children_eids), 6)
+        self.assertEqual(len(comet_children_eids), 6)
         self.failUnless(self.doc.eid in comet_children_eids)
         tracker_children = list(transitive_closure_of(self.tracker, 'reverse_subproject_of'))
-        self.assertEquals(len(tracker_children), 2)
+        self.assertEqual(len(tracker_children), 2)
 
     def test_loop_safety_belt(self):
         self.assertRaises(ValidationError, self.execute,
@@ -581,14 +581,14 @@ class SubProjectTC(CubicWebTC):
                                    ('tracker', False, False),
                                    ('lgc', False, True)):
             proj = getattr(self, proj)
-            self.assertEquals(proj.cw_adapt_to('ITree').is_root(), rootp)
-            self.assertEquals(proj.cw_adapt_to('ITree').is_leaf(), leafp)
+            self.assertEqual(proj.cw_adapt_to('ITree').is_root(), rootp)
+            self.assertEqual(proj.cw_adapt_to('ITree').is_leaf(), leafp)
 
     def test_tickets(self):
         self.setup_versions()
         self.setup_tickets()
-        self.assertEquals(len(self.lgc.reverse_concerns), 1)
-        self.assertEquals(self.execute('Any COUNT(T) WHERE T done_in V, V in_state S, S name "%s"'
+        self.assertEqual(len(self.lgc.reverse_concerns), 1)
+        self.assertEqual(self.execute('Any COUNT(T) WHERE T done_in V, V in_state S, S name "%s"'
                                        % self.versions_wf_map['inprogress']).rows[0][0],
                           3)
 
