@@ -72,7 +72,7 @@ class TrackerTCMixIn(object):
         self.failUnless(entity.modification_date > olddate)
 
     def assertPossibleTransitions(self, entity, expected):
-        self.assertListEquals(ptransitions(entity), sorted(expected))
+        self.assertListEqual(ptransitions(entity), sorted(expected))
 
 
 class TrackerBaseTC(TrackerTCMixIn, CubicWebTC):
@@ -112,16 +112,18 @@ class SecurityTC(TrackerTCMixIn, CubicWebTC):
         self.create_user('prj2client', groups=('users', 'project2clients'))
         self.maxeid = self.execute('Any MAX(X)')[0][0]
         cachedperms = self.execute('Any UL, PN WHERE U has_group_permission P, U login UL, P label PN')
-        self.assertEquals(len(cachedperms), 4)
-        self.assertDictEquals(dict(cachedperms),
+        self.assertEqual(len(cachedperms), 4)
+        self.assertDictEqual(dict(cachedperms),
                           {'prj1developer': 'cubicwebdevelopers',
                            'prj1client':    'cubicwebclients',
                            'prj2developer': 'project2developers',
                            'prj2client':    'project2clients'})
 
-    def mylogin(self, user):
+    def mylogin(self, user, **kwargs):
         if not user in self.__cnxs:
-            self.__cnxs[user] = self.login(user)
+            if user == 'narval':
+                kwargs['password'] = 'narval0'
+            self.__cnxs[user] = self.login(user, autoclose=False, **kwargs)
         return self.__cnxs[user]
 
     def _test_tr_fail(self, user, x, trname):
@@ -165,10 +167,7 @@ class ThreeSourcesConfiguration(ApptestConfiguration):
                          'mapping-file': 'extern_mapping.py'
                          #'base-url': '',
                          }
-        if self._enabled_sources is None:
-            return res
-        return dict((uri, config) for uri, config in res.items()
-                    if uri in self._enabled_sources)
+        return res
 
 
 class ExternalSourceConfiguration(TestServerConfiguration):
